==> hermes-consumers-0.7.6-sources.jar: pl/allegro/tech/hermes/consumers/consumer/offset/OffsetCommitQueueMonitor.java <==
package pl.allegro.tech.hermes.consumers.consumer.offset;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import pl.allegro.tech.hermes.api.Subscription;
import pl.allegro.tech.hermes.common.metric.HermesMetrics;
import pl.allegro.tech.hermes.common.metric.counter.MetricsDeltaCalculator;
import pl.allegro.tech.hermes.common.time.Clock;

public class OffsetCommitQueueMonitor {

    private static final Logger LOGGER = LoggerFactory.getLogger(OffsetCommitQueueMonitor.class);

    private final Subscription subscription;
    private final Integer partition;
    private final HermesMetrics hermesMetrics;
    private final Clock clock;

    private final MetricsDeltaCalculator metricsDeltaCalculator;

    private Long offset;
    private Long offsetChangeTimestampSec;

    private final long offsetCommitQueueAlertSize;
    private final long offsetCommitAdditionalIdlePeriodAlert;

    public OffsetCommitQueueMonitor(Subscription subscription, Integer partition, HermesMetrics hermesMetrics, Clock clock, int offsetCommitAdditionalIdlePeriodAlert, int offsetCommitQueueAlertSize) {
        this.subscription = subscription;
        this.partition = partition;
        this.hermesMetrics = hermesMetrics;
        this.clock = clock;

        this.offsetCommitAdditionalIdlePeriodAlert = offsetCommitAdditionalIdlePeriodAlert;
        this.offsetCommitQueueAlertSize = offsetCommitQueueAlertSize;
        this.metricsDeltaCalculator = new MetricsDeltaCalculator();

    }

    public void nothingNewToCommit(long size, long firstOffset) {
        if (offset != null && firstOffset == offset) {
            if (alertSizeExceeded(size) || idlePeriodDurationAlert()) {
                reportIdlenessPeriod();
                LOGGER.warn("Commit queue idle for partition {} / {}. Current size {}", subscription.getName(), partition, size);
            }
        } else {
            this.offset = firstOffset;
            this.offsetChangeTimestampSec = currentTimestampSec();
        }
    }

    public void newOffsetCommit() {
        removeCounter();
        this.offset = null;
        this.offsetChangeTimestampSec = null;
    }

    private boolean idlePeriodDurationAlert() {
        return (offsetChangeTimestampSec + offsetCommitAdditionalIdlePeriodAlert + subscription.getSubscriptionPolicy().getMessageTtl() < currentTimestampSec());
    }

    private boolean alertSizeExceeded(long size) {
        return size > offsetCommitQueueAlertSize;
    }

    private void removeCounter() {
        hermesMetrics.removeCounterForOffsetCommitIdlePeriod(subscription, partition);
        metricsDeltaCalculator.clear();
    }

    private void reportIdlenessPeriod() {
        long idlenessPeriod = currentTimestampSec() - offsetChangeTimestampSec;
        hermesMetrics.counterForOffsetCommitIdlePeriod(subscription, partition).inc(
                metricsDeltaCalculator.calculateDelta(subscription.getId() + "_" + partition, idlenessPeriod)
        );
    }

    private long currentTimestampSec() {
        return clock.getTime() / 1000;
    }
}

==> hermes-consumers-0.8.2-rc1-sources.jar: pl/allegro/tech/hermes/consumers/consumer/offset/OffsetCommitQueueMonitor.java <==
package pl.allegro.tech.hermes.consumers.consumer.offset;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import pl.allegro.tech.hermes.api.Subscription;
import pl.allegro.tech.hermes.common.metric.HermesMetrics;
import pl.allegro.tech.hermes.common.metric.counter.MetricsDeltaCalculator;
import pl.allegro.tech.hermes.common.time.Clock;

public class OffsetCommitQueueMonitor {

    private static final Logger LOGGER = LoggerFactory.getLogger(OffsetCommitQueueMonitor.class);

    private final Subscription subscription;
    private final TopicPartition topicPartition;
    private final HermesMetrics hermesMetrics;
    private final Clock clock;

    private final MetricsDeltaCalculator metricsDeltaCalculator;

    private Long offset;
    private Long offsetChangeTimestampSec;

    private final long offsetCommitQueueAlertSize;
    private final long offsetCommitAdditionalIdlePeriodAlert;

    public OffsetCommitQueueMonitor(Subscription subscription, TopicPartition topicPartition, HermesMetrics hermesMetrics,
                                    Clock clock, int offsetCommitAdditionalIdlePeriodAlert, int offsetCommitQueueAlertSize) {
        this.subscription = subscription;
        this.topicPartition = topicPartition;
        this.hermesMetrics = hermesMetrics;
        this.clock = clock;

        this.offsetCommitAdditionalIdlePeriodAlert = offsetCommitAdditionalIdlePeriodAlert;
        this.offsetCommitQueueAlertSize = offsetCommitQueueAlertSize;
        this.metricsDeltaCalculator = new MetricsDeltaCalculator();

    }

    public void nothingNewToCommit(long size, long firstOffset) {
        if (offset != null && firstOffset == offset) {
            if (alertSizeExceeded(size) || idlePeriodDurationAlert()) {
                reportIdlenessPeriod();
                LOGGER.warn("Commit queue idle for partition {} of kafka topic {} and subscription {}. Current size {}",
                        topicPartition.getPartition(), topicPartition.getTopic(), subscription.getName(), size);
            }
        } else {
            this.offset = firstOffset;
            this.offsetChangeTimestampSec = currentTimestampSec();
        }
    }

    public void newOffsetCommit() {
        removeCounter();
        this.offset = null;
        this.offsetChangeTimestampSec = null;
    }

    private boolean idlePeriodDurationAlert() {
        return (offsetChangeTimestampSec + offsetCommitAdditionalIdlePeriodAlert + subscription.getSubscriptionPolicy().getMessageTtl() < currentTimestampSec());
    }

    private boolean alertSizeExceeded(long size) {
        return size > offsetCommitQueueAlertSize;
    }

    private void removeCounter() {
        hermesMetrics.removeCounterForOffsetCommitIdlePeriod(subscription, topicPartition.getTopic(), topicPartition.getPartition());
        metricsDeltaCalculator.clear();
    }

    private void reportIdlenessPeriod() {
        long idlenessPeriod = currentTimestampSec() - offsetChangeTimestampSec;
        hermesMetrics.counterForOffsetCommitIdlePeriod(subscription, topicPartition.getTopic(), topicPartition.getPartition()).inc(
                metricsDeltaCalculator.calculateDelta(deltaKey(), idlenessPeriod)
        );
    }

    private String deltaKey() {
        return subscription.getId() + "_" + topicPartition.getTopic() + "_" + topicPartition.getPartition();
    }

    private long currentTimestampSec() {
        return clock.getTime() / 1000;
    }
}
